﻿using System;
using System.IdentityModel.Tokens.Jwt;
using System.IO;
using System.Security.Claims;
using System.Security.Cryptography.X509Certificates;
using IdentityModel;
using Microsoft.IdentityModel.Tokens;

namespace csharp_jwt_sample
{
    class Program
    {
        static void Main(string[] args)
        {
            var password = Environment.GetEnvironmentVariable("CERT_PASSWORD");
            var cert = new X509Certificate2(File.ReadAllBytes("certificate.pfx"), password);

            var now = DateTime.UtcNow;
            var clientId = args.Length >= 1 ? args[0] : "CLIENT_ID";

            var audience = "https://secure.stitch.money/connect/token";
            var issuer = clientId;
            var subject = clientId;
            var jti = Guid.NewGuid().ToString(); // Needs to be a unique value each time
            var issuedAt = now.ToEpochTime().ToString();
            var notBefore = now;
            var expiresAt = now + TimeSpan.FromSeconds(60); // Should be a small value after now


            var token = new JwtSecurityToken(
                issuer,
                audience,
                new[]
                {
                    new Claim(JwtClaimTypes.JwtId, jti),
                    new Claim(JwtClaimTypes.Subject, subject),
                    new Claim(JwtClaimTypes.IssuedAt, issuedAt, ClaimValueTypes.Integer64),
                },
                notBefore,
                expiresAt,
                new SigningCredentials(
                    new X509SecurityKey(cert),
                    SecurityAlgorithms.RsaSha256
                )
            );
            var tokenHandler = new JwtSecurityTokenHandler();
            var tokenString = tokenHandler.WriteToken(token);

            System.Console.WriteLine($@"
                Your jwt:
                {tokenString}
            ");
        }
    }
}
